@@ -1,5 +1,6 @@
 import os
 from typing import Dict
+from typing import Optional
 from typing import Union
 
 import simplejson as json
@@ -19,6 +20,28 @@ else:
     _component_func = components.declare_component("st_echarts", path=build_dir)
 
 
+class Map:
+    def __init__(
+        self, map_name: str, geo_json: Dict, special_areas: Optional[Dict] = None
+    ) -> None:
+        self.map_name: str = map_name
+        self.geo_json: Dict = geo_json
+        self.special_areas: Optional[Dict] = special_areas
+
+    def to_json(self):
+        return {
+            "mapName": self.map_name,
+            "geoJson": self.geo_json,
+            "specialAreas": self.special_areas,
+        }
+
+
+class JsCode:
+    def __init__(self, js_code: str):
+        js_placeholder = "--x_x--0_0--"
+        self.js_code = f"{js_placeholder}{js_code}{js_placeholder}"
+
+
 def st_echarts(
     options: Dict,
     theme: Union[str, Dict] = "",
@@ -26,6 +49,7 @@ def st_echarts(
     height: str = "300px",
     width: str = "100%",
     renderer: str = "canvas",
+    map: Map = None,
     key: str = None,
 ):
     """Display an ECharts instance in Streamlit
@@ -45,6 +69,8 @@ def st_echarts(
         Width of ECharts chart
     renderer: {'canvas', 'svg'}
         Renderer for displaying chart
+    map: Map
+        Details of GeoJSON map to register into echarts
     key: str
         An optional string to use as the unique key for the widget. 
         Assign a key so the component is not remount every time the script is rerun.
@@ -58,6 +84,7 @@ def st_echarts(
         height=height,
         width=width,
         renderer=renderer,
+        map=map.to_json() if map is not None else None,
         key=key,
         default=None,
     )
@@ -70,6 +97,7 @@ def st_pyecharts(
     height: str = "300px",
     width: str = "100%",
     renderer: str = "canvas",
+    map: Map = None,
     key: str = None,
 ):
     """Display a PyECharts instance in Streamlit
@@ -89,6 +117,8 @@ def st_pyecharts(
         Width of ECharts chart
     renderer: {'canvas', 'svg'}
         Renderer for displaying chart
+    map: Map
+        Details of GeoJSON map to register into echarts
     key: str
         An optional string to use as the unique key for the widget. 
         Assign a key so the component is not remount every time the script is rerun.
@@ -100,12 +130,7 @@ def st_pyecharts(
         events=events,
         height=height,
         width=width,
-        key=key,
         renderer=renderer,
+        map=map,
+        key=key,
     )
-
-
-class JsCode:
-    def __init__(self, js_code: str):
-        js_placeholder = "--x_x--0_0--"
-        self.js_code = f"{js_placeholder}{js_code}{js_placeholder}"
